==> ckeditor_4.9.2%2Bdfsg.orig.tar.xz: ckeditor-dev-4.9.2/plugins/forms/lang/bg.js <==
/*
Copyright (c) 2003-2018, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
*/
CKEDITOR.plugins.setLang( 'forms', 'bg', {
	button: {
		title: 'Настройки на бутона',
		text: 'Текст (стойност)',
		type: 'Тип',
		typeBtn: 'Бутон',
		typeSbm: 'Добави',
		typeRst: 'Нулиране'
	},
	checkboxAndRadio: {
		checkboxTitle: 'Checkbox Properties',
		radioTitle: 'Настройки на радиобутон',
		value: 'Стойност',
		selected: 'Избрано',
		required: 'Required' // MISSING
	},
	form: {
		title: 'Настройки на формата',
		menu: 'Настройки на формата',
		action: 'Действие',
		method: 'Метод',
		encoding: 'Кодиране'
	},
	hidden: {
		title: 'Настройки за скрито поле',
		name: 'Име',
		value: 'Стойност'
	},
	select: {
		title: 'Selection Field Properties',
		selectInfo: 'Select Info',
		opAvail: 'Налични опции',
		value: 'Стойност',
		size: 'Размер',
		lines: 'линии',
		chkMulti: 'Allow multiple selections',
		required: 'Required', // MISSING
		opText: 'Текст',
		opValue: 'Стойност',
		btnAdd: 'Добави',
		btnModify: 'Промени',
		btnUp: 'На горе',
		btnDown: 'На долу',
		btnSetValue: 'Set as selected value',
		btnDelete: 'Изтриване'
	},
	textarea: {
		title: 'Опции за текстовата зона',
		cols: 'Колони',
		rows: 'Редове'
	},
	textfield: {
		title: 'Настройки за текстово поле',
		name: 'Име',
		value: 'Стойност',
		charWidth: 'Ширина на знаците',
		maxChars: 'Макс. знаци',
		required: 'Required', // MISSING
		type: 'Тип',
		typeText: 'Текст',
		typePass: 'Парола',
		typeEmail: 'Email',
		typeSearch: 'Търсене',
		typeTel: 'Телефонен номер',
		typeUrl: 'Уеб адрес'
	}
} );

==> ckeditor_4.10.0%2Bdfsg.orig.tar.xz: ckeditor-dev-4.10.0/plugins/forms/lang/bg.js <==
/*
Copyright (c) 2003-2018, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
*/
CKEDITOR.plugins.setLang( 'forms', 'bg', {
	button: {
		title: 'Настройки на бутон',
		text: 'Текст (стойност)',
		type: 'Тип',
		typeBtn: 'Бутон',
		typeSbm: 'Добави',
		typeRst: 'Нулиране'
	},
	checkboxAndRadio: {
		checkboxTitle: 'Настройки на чекбокс',
		radioTitle: 'Настройки на радиобутон',
		value: 'Стойност',
		selected: 'Избрано',
		required: 'Задължително'
	},
	form: {
		title: 'Настройки на форма',
		menu: 'Настройки на форма',
		action: 'Действие',
		method: 'Метод',
		encoding: 'Кодиране'
	},
	hidden: {
		title: 'Настройки на скрито поле',
		name: 'Име',
		value: 'Стойност'
	},
	select: {
		title: 'Настройки на поле за избор',
		selectInfo: 'Селект инфо',
		opAvail: 'Налични опции',
		value: 'Стойност',
		size: 'Размер',
		lines: 'линии',
		chkMulti: 'Разрешаване на няколко избора',
		required: 'Задължително',
		opText: 'Текст',
		opValue: 'Стойност',
		btnAdd: 'Добави',
		btnModify: 'Промени',
		btnUp: 'Нагоре',
		btnDown: 'Надолу',
		btnSetValue: 'Задай като избрана стойност',
		btnDelete: 'Изтриване'
	},
	textarea: {
		title: 'Настройки на текстова зона',
		cols: 'Колони',
		rows: 'Редове'
	},
	textfield: {
		title: 'Настройки на текстово поле',
		name: 'Име',
		value: 'Стойност',
		charWidth: 'Ширина на знаците',
		maxChars: 'Макс. знаци',
		required: 'Задължително',
		type: 'Тип',
		typeText: 'Текст',
		typePass: 'Парола',
		typeEmail: 'Имейл',
		typeSearch: 'Търсене',
		typeTel: 'Телефонен номер',
		typeUrl: 'Уеб адрес'
	}
} );
